@@ -20,11 +20,10 @@ import platform
 import socket
 import sys
 import time
+import urllib
 import uuid
 
 import requests
-import six
-from six.moves import urllib
 
 import keystoneauth1
 from keystoneauth1 import _utils as utils
@@ -48,7 +47,7 @@ DEFAULT_USER_AGENT = 'keystoneauth1/%s %s %s/%s' % (
 # NOTE(jamielennox): Clients will likely want to print more than json. Please
 # propose a patch if you have a content type you think is reasonable to print
 # here and we'll add it to the list as required.
-_LOG_CONTENT_TYPES = set(['application/json'])
+_LOG_CONTENT_TYPES = set(['application/json', 'text/plain'])
 
 _MAX_RETRY_INTERVAL = 60.0
 _EXPONENTIAL_DELAY_START = 0.5
@@ -83,6 +82,8 @@ def _mv_legacy_headers_for_service(mv_service_type):
         headers.append("X-OpenStack-Nova-API-Version")
     elif mv_service_type == "baremetal":
         headers.append("X-OpenStack-Ironic-API-Version")
+    elif mv_service_type in ["sharev2", "shared-file-system"]:
+        headers.append("X-OpenStack-Manila-API-Version")
     return headers
 
 
@@ -90,18 +91,11 @@ def _sanitize_headers(headers):
     """Ensure headers are strings and not bytes."""
     str_dict = {}
     for k, v in headers.items():
-        if six.PY3:
-            # requests expects headers to be str type in python3, which means
-            # if we get a bytes we need to decode it into a str
-            k = k.decode('ASCII') if isinstance(k, six.binary_type) else k
-            if v is not None:
-                v = v.decode('ASCII') if isinstance(v, six.binary_type) else v
-        else:
-            # requests expects headers to be str type in python2, which means
-            # if we get a unicode we need to encode it to ASCII into a str
-            k = k.encode('ASCII') if isinstance(k, six.text_type) else k
-            if v is not None:
-                v = v.encode('ASCII') if isinstance(v, six.text_type) else v
+        # requests expects headers to be str type in python3, which means
+        # if we get a bytes we need to decode it into a str
+        k = k.decode('ASCII') if isinstance(k, bytes) else k
+        if v is not None:
+            v = v.decode('ASCII') if isinstance(v, bytes) else v
         str_dict[k] = v
     return str_dict
 
@@ -124,9 +118,9 @@ class _JSONEncoder(json.JSONEncoder):
         if isinstance(o, datetime.datetime):
             return o.isoformat()
         if isinstance(o, uuid.UUID):
-            return six.text_type(o)
+            return str(o)
         if netaddr and isinstance(o, netaddr.IPAddress):
-            return six.text_type(o)
+            return str(o)
 
         return super(_JSONEncoder, self).default(o)
 
@@ -483,7 +477,7 @@ class Session(object):
         # so we need to actually check that this is False.
         if self.verify is False:
             string_parts.append('--insecure')
-        elif isinstance(self.verify, six.string_types):
+        elif isinstance(self.verify, str):
             string_parts.append('--cacert "%s"' % self.verify)
 
         if method:
@@ -507,7 +501,7 @@ class Session(object):
         if json:
             data = self._json.encode(json)
         if data:
-            if isinstance(data, six.binary_type):
+            if isinstance(data, bytes):
                 try:
                     data = data.decode("ascii")
                 except UnicodeDecodeError:
@@ -614,6 +608,14 @@ class Session(object):
         if (service_type.startswith('volume') or
                 service_type == 'block-storage'):
             service_type = 'volume'
+        elif service_type.startswith('share'):
+            # NOTE(gouthamr) manila doesn't honor the "OpenStack-API-Version"
+            # header yet, but sending it does no harm - when the service
+            # honors this header, it'll use the standardized name in the
+            # service-types-authority and not the legacy name in the cloud's
+            # service catalog
+            service_type = 'shared-file-system'
+
         headers.setdefault('OpenStack-API-Version',
                            '{service_type} {microversion}'.format(
                                service_type=service_type,
